@@ -8,14 +8,14 @@ config = ConfigParser()
 config.read('config.ini')
 
 dbname = config["bot"]["bot_name"]
-class WhatsappUser(mongoengine.Document):
+class WhatsAppUser(mongoengine.Document):
     ProfileName = mongoengine.StringField(required=True)
     WaId = mongoengine.StringField(required=True, max_length=50)
     entry_time = mongoengine.DateTimeField(default=datetime.datetime.utcnow)
     meta = {'db_alias': dbname}
 
-class WhatsappInteraction(mongoengine.Document):
-    user = mongoengine.ReferenceField(WhatsappUser)
+class WhatsAppInteraction(mongoengine.Document):
+    user = mongoengine.ReferenceField(WhatsAppUser)
     Latitude = mongoengine.StringField()
     Longitude = mongoengine.StringField()
     SmsMessageSid = mongoengine.StringField()
@@ -38,3 +38,8 @@ class WhatsappInteraction(mongoengine.Document):
     date = mongoengine.DateTimeField(default=datetime.datetime.utcnow)
     meta = {'db_alias': dbname}
 
+class WhatsAppUserContextState(mongoengine.Document):
+    WaId = mongoengine.StringField(primary_key=True)
+    context = mongoengine.DictField()
+    state = mongoengine.StringField()
+    meta = {'db_alias': dbname}
\ No newline at end of file
